@@ -41,7 +41,7 @@
 #include "hud_training.h"
 #include "joystick.h"
 #include "bonus.h"
-//MV#import "sharedGeneralFunctions.h"
+#include "accelerometer.h"
 
 /* Time constant for automatic steering centering (s) */
 #define TURN_DECAY_TIME_CONSTANT 0.5
@@ -88,10 +88,9 @@ void racing_init(void)
     winsys_set_display_func( main_loop );
     winsys_set_idle_func( main_loop );
     winsys_set_reshape_func( reshape );
-    winsys_set_mouse_func( NULL );
+    winsys_set_mouse_func( racing_mouse_func );
     winsys_set_motion_func( NULL );
     winsys_set_passive_motion_func( NULL );
-    winsys_set_mouse_func( NULL );
         
     /* Initialize view */
     if ( getparam_view_mode() < 0 || 
@@ -175,6 +174,7 @@ void racing_loop( scalar_t time_step )
     scalar_t terrain_weights[NumTerrains];
     int new_terrain = 0;
     int slide_volume;
+    int ax,ay,az;
 
     
     dir = plyr->vel;
@@ -293,12 +293,13 @@ void racing_loop( scalar_t time_step )
             plyr->control.turn_animation = 0.0;
         }
     }
-/*    scalar_t iPhone_turn_fact=0; //MV accelerometerTurnFact();
 
-    iPhone_turn_fact=0; //MV accelerometerTurnFact();
-*/    
+    accel_read(&ax,&ay,&az);
+    scalar_t iPhone_turn_fact=0; //MV accelerometerTurnFact();
+    iPhone_turn_fact=-ax/500.0;
+    
     /*left_turn and right_turn are informations useful for tricks*/
-/*    if (iPhone_turn_fact>TURN_FACTOR_LIMIT) {
+    if (iPhone_turn_fact>TURN_FACTOR_LIMIT) {
         left_turn=false;
         right_turn=true;
     }
@@ -309,7 +310,7 @@ void racing_loop( scalar_t time_step )
     
     plyr->control.turn_fact = iPhone_turn_fact;
     plyr->control.turn_animation = iPhone_turn_fact;
-*/    
+    
     
     /*
      * Paddling
@@ -604,7 +605,7 @@ void racing_register()
     status |= add_keymap_entry( RACING, CONFIGURABLE_KEY, 
                                "l", getparam_turn_right_key, turn_right_cb );
     status |= add_keymap_entry( RACING, CONFIGURABLE_KEY, 
-                               "m", getparam_trick_modifier_key, 
+                               "d", getparam_trick_modifier_key, 
                                trick_modifier_cb );
     status |= add_keymap_entry( RACING, CONFIGURABLE_KEY, 
                                "b", getparam_brake_key, brake_cb );
@@ -633,3 +634,38 @@ void racing_register()
     
     register_loop_funcs( RACING, racing_init, racing_loop, racing_term );
 }
+
+void racing_mouse_func( int button, int state, int x, int y ) {
+    static int noquit = 1;
+    printf("racing_mouse_func %d %d %d\n", x, y, noquit);
+    /* Check screen controls */
+    paddling = False;
+    braking = False;
+    charging = False;
+    if (state == SDL_PRESSED) {
+        noquit = 1;
+        if (x > 680 && y > 360)
+            paddling = True;
+
+        if (x < 120 && y >360)
+            braking = True;
+
+        if (x > 340 && x < 460 && y > 180 && y < 300) {
+            noquit = 0;
+            g_game.race_paused = True;
+            set_game_mode( PAUSED );
+        }
+
+        if (x > 680 && y < 120)
+            charging = True;
+
+    }
+    else if ( !noquit &&g_game.prev_mode == PAUSED && x < 120 && y > 360 && (state == SDL_RELEASED) ) {
+        g_game.race_aborted = True;
+        set_game_mode( GAME_OVER );
+    }
+
+    player_data_t *plyr = get_player_data( local_player() );
+    if (paddling) plyr->control.is_accelerating = true; else  plyr->control.is_accelerating = false;
+}
+
